@@ -504,11 +504,16 @@ private:
 	ArdourWidgets::ArdourVSpacer recpunch_spacer;
 	ArdourWidgets::ArdourVSpacer monitoring_spacer;
 	ArdourWidgets::ArdourVSpacer latency_spacer;
+	ArdourWidgets::ArdourVSpacer monitor_spacer;
 
 	ArdourWidgets::ArdourButton monitor_in_button;
 	ArdourWidgets::ArdourButton monitor_disk_button;
 	ArdourWidgets::ArdourButton auto_input_button;
 
+	ArdourWidgets::ArdourButton monitor_dim_button;
+	ArdourWidgets::ArdourButton monitor_mono_button;
+	ArdourWidgets::ArdourButton monitor_mute_button;
+
 	Gtk::Label   punch_label;
 	Gtk::Label   layered_label;
 
@@ -619,6 +624,8 @@ private:
 	Gtk::Label session_path_label;
 	void update_path_label ();
 
+	Gtk::Label snapshot_name_label;
+
 	void every_second ();
 	void every_point_one_seconds ();
 	void every_point_zero_something_seconds ();
