@@ -726,6 +726,7 @@ ARDOUR_UI::build_menu_bar ()
 
 	EventBox* ev_dsp = manage (new EventBox);
 	EventBox* ev_path = manage (new EventBox);
+	EventBox* ev_name = manage (new EventBox);
 	EventBox* ev_audio = manage (new EventBox);
 	EventBox* ev_format = manage (new EventBox);
 	EventBox* ev_timecode = manage (new EventBox);
@@ -745,10 +746,12 @@ ARDOUR_UI::build_menu_bar ()
 	sample_rate_label.set_use_markup ();
 	format_label.set_name ("Format");
 	session_path_label.set_name ("Path");
+	snapshot_name_label.set_name ("Name");
 	format_label.set_use_markup ();
 
 	ev_dsp->add (dsp_load_label);
 	ev_path->add (session_path_label);
+	ev_name->add (snapshot_name_label);
 	ev_audio->add (sample_rate_label);
 	ev_format->add (format_label);
 	ev_timecode->add (timecode_format_label);
@@ -774,6 +777,7 @@ ARDOUR_UI::build_menu_bar ()
 	hbox->pack_end (*ev_timecode, false, false, 6);
 	hbox->pack_end (*ev_format, false, false, 6);
 	hbox->pack_end (peak_thread_work_label, false, false, 6);
+	hbox->pack_end (*ev_name, false, false, 6);
 	hbox->pack_end (*ev_path, false, false, 6);
 
 	menu_hbox.pack_end (*ev, true, true, 2);
@@ -782,6 +786,7 @@ ARDOUR_UI::build_menu_bar ()
 	menu_bar_base.add (menu_hbox);
 
 	_status_bar_visibility.add (&session_path_label    ,X_("Path"),      _("Path to Session"), false);
+	_status_bar_visibility.add (&snapshot_name_label   ,X_("Name"),      _("Snapshot Name and Modified Indicator"), false);
 	_status_bar_visibility.add (&peak_thread_work_label,X_("Peakfile"),  _("Active Peak-file Work"), false);
 	_status_bar_visibility.add (&format_label,          X_("Format"),    _("File Format"), false);
 	_status_bar_visibility.add (&timecode_format_label, X_("TCFormat"),  _("Timecode Format"), false);
@@ -798,6 +803,7 @@ ARDOUR_UI::build_menu_bar ()
 	ev_dsp->signal_button_press_event().connect (sigc::mem_fun (*this, &ARDOUR_UI::xrun_button_press));
 	ev_dsp->signal_button_release_event().connect (sigc::mem_fun (*this, &ARDOUR_UI::xrun_button_release));
 	ev_path->signal_button_press_event().connect (sigc::mem_fun (*this, &ARDOUR_UI::path_button_press));
+	ev_name->signal_button_press_event().connect (sigc::mem_fun (*this, &ARDOUR_UI::path_button_press));
 	ev_audio->signal_button_press_event().connect (sigc::mem_fun (*this, &ARDOUR_UI::audio_button_press));
 	ev_format->signal_button_press_event().connect (sigc::mem_fun (*this, &ARDOUR_UI::format_button_press));
 	ev_timecode->signal_button_press_event().connect (sigc::mem_fun (*this, &ARDOUR_UI::timecode_button_press));
