@@ -421,52 +421,17 @@ AUPluginUI::AUPluginUI (boost::shared_ptr<PluginInsert> insert)
 
 	/* stuff some stuff into the top of the window */
 
-	HBox* smaller_hbox = manage (new HBox);
-
-	smaller_hbox->set_spacing (6);
-	smaller_hbox->pack_start (latency_button, false, false, 4);
-	smaller_hbox->pack_start (pin_management_button, false, false, 4);
-	smaller_hbox->pack_start (preset_label, false, false, 4);
-	smaller_hbox->pack_start (_preset_modified, false, false);
-	smaller_hbox->pack_start (_preset_combo, false, false);
-	smaller_hbox->pack_start (add_button, false, false);
-	smaller_hbox->pack_start (save_button, false, false);
-	smaller_hbox->pack_start (delete_button, false, false);
-	if (has_descriptive_presets ()) {
-		smaller_hbox->pack_start (preset_browser_button, false, false);
-	}
-#if 0
-	/* one day these might be useful with an AU plugin, but not yet */
-	smaller_hbox->pack_start (automation_mode_label, false, false);
-	smaller_hbox->pack_start (automation_mode_selector, false, false);
-#endif
-	if (insert->controls().size() > 0) {
-		smaller_hbox->pack_start (reset_button, false, false);
-	}
-	smaller_hbox->pack_start (bypass_button, false, true);
-
-	VBox* v1_box = manage (new VBox);
-	VBox* v2_box = manage (new VBox);
-
-	v1_box->pack_start (*smaller_hbox, false, true);
-	v2_box->pack_start (focus_button, false, true);
 
 	top_box.set_homogeneous (false);
 	top_box.set_spacing (6);
 	top_box.set_border_width (6);
+	add_common_widgets (&top_box);
 
-	top_box.pack_end (*v2_box, false, false);
-	top_box.pack_end (*v1_box, false, false);
-
-	set_spacing (6);
+	set_spacing (0);
 	pack_start (top_box, false, false);
 	pack_start (low_box, true, true);
 
-	preset_label.show ();
-	_preset_combo.show ();
-	automation_mode_label.show ();
-	automation_mode_selector.show ();
-	bypass_button.show ();
+	top_box.show_all ();
 	top_box.show ();
 	low_box.show ();
 
@@ -626,7 +591,7 @@ AUPluginUI::create_cocoa_view ()
 
 	if ((result == noErr) && (numberOfClasses > 0) ) {
 
-		DEBUG_TRACE(DEBUG::AudioUnits,
+		DEBUG_TRACE(DEBUG::AudioUnitGUI,
 			    string_compose ( "based on %1, there are %2 cocoa UI classes\n", dataSize, numberOfClasses));
 
 		cocoaViewInfo = (AudioUnitCocoaViewInfo *)malloc(dataSize);
@@ -643,12 +608,12 @@ AUPluginUI::create_cocoa_view ()
 			// we only take the first view in this example.
 			factoryClassName	= (NSString *)cocoaViewInfo->mCocoaAUViewClass[0];
 
-			DEBUG_TRACE (DEBUG::AudioUnits, string_compose ("the factory name is %1 bundle is %2\n",
+			DEBUG_TRACE (DEBUG::AudioUnitGUI, string_compose ("the factory name is %1 bundle is %2\n",
 									[factoryClassName UTF8String], CocoaViewBundlePath));
 
 		} else {
 
-			DEBUG_TRACE (DEBUG::AudioUnits, string_compose ("No cocoaUI property cocoaViewInfo = %1\n", cocoaViewInfo));
+			DEBUG_TRACE (DEBUG::AudioUnitGUI, string_compose ("No cocoaUI property cocoaViewInfo = %1\n", cocoaViewInfo));
 
 			if (cocoaViewInfo != NULL) {
 				free (cocoaViewInfo);
@@ -662,14 +627,14 @@ AUPluginUI::create_cocoa_view ()
 	if (CocoaViewBundlePath && factoryClassName) {
 		NSBundle *viewBundle	= [NSBundle bundleWithPath:[CocoaViewBundlePath path]];
 
-		DEBUG_TRACE (DEBUG::AudioUnits, string_compose ("tried to create bundle, result = %1\n", viewBundle));
+		DEBUG_TRACE (DEBUG::AudioUnitGUI, string_compose ("tried to create bundle, result = %1\n", viewBundle));
 
 		if (viewBundle == NULL) {
 			error << _("AUPluginUI: error loading AU view's bundle") << endmsg;
 			return -1;
 		} else {
 			Class factoryClass = [viewBundle classNamed:factoryClassName];
-			DEBUG_TRACE (DEBUG::AudioUnits, string_compose ("tried to create factory class, result = %1\n", factoryClass));
+			DEBUG_TRACE (DEBUG::AudioUnitGUI, string_compose ("tried to create factory class, result = %1\n", factoryClass));
 			if (!factoryClass) {
 				error << _("AUPluginUI: error getting AU view's factory class from bundle") << endmsg;
 				return -1;
@@ -687,12 +652,12 @@ AUPluginUI::create_cocoa_view ()
 				return -1;
 			}
 
-			DEBUG_TRACE (DEBUG::AudioUnits, "got a factory instance\n");
+			DEBUG_TRACE (DEBUG::AudioUnitGUI, "got a factory instance\n");
 
 			// make a view
 			au_view = [factory uiViewForAudioUnit:*au->get_au() withSize:NSZeroSize];
 
-			DEBUG_TRACE (DEBUG::AudioUnits, string_compose ("view created @ %1\n", au_view));
+			DEBUG_TRACE (DEBUG::AudioUnitGUI, string_compose ("view created @ %1\n", au_view));
 
 			// cleanup
 			[CocoaViewBundlePath release];
@@ -709,10 +674,10 @@ AUPluginUI::create_cocoa_view ()
 
 	if (!wasAbleToLoadCustomView) {
 		// load generic Cocoa view
-		DEBUG_TRACE (DEBUG::AudioUnits, string_compose ("Loading generic view using %1 -> %2\n", au,
+		DEBUG_TRACE (DEBUG::AudioUnitGUI, string_compose ("Loading generic view using %1 -> %2\n", au,
 								au->get_au()));
 		au_view = [[AUGenericView alloc] initWithAudioUnit:*au->get_au()];
-		DEBUG_TRACE (DEBUG::AudioUnits, string_compose ("view created @ %1\n", au_view));
+		DEBUG_TRACE (DEBUG::AudioUnitGUI, string_compose ("view created @ %1\n", au_view));
 		[(AUGenericView *)au_view setShowsExpertParameters:1];
 	}
 
@@ -897,6 +862,13 @@ AUPluginUI::cocoa_view_resized ()
             last_au_frame.origin.y != new_frame.origin.y) {
                 new_frame.origin = last_au_frame.origin;
                 [au_view setFrame:new_frame];
+
+		NSArray* subviews = [au_view subviews];
+		for (unsigned long i = 0; i < [subviews count]; ++i) {
+			NSView* subview = [subviews objectAtIndex:i];
+			[subview setFrame:NSMakeRect (0, 0, new_frame.size.width, new_frame.size.height)];
+		}
+
                 /* also be sure to redraw the topbox because this can
                    also go wrong.
                  */
@@ -1113,9 +1085,15 @@ AUPluginUI::parent_cocoa_window ()
 	gtk_widget_translate_coordinates(
 			GTK_WIDGET(low_box.gobj()),
 			GTK_WIDGET(low_box.get_parent()->gobj()),
-			8, 6, &xx, &yy);
+			0, 0, &xx, &yy);
 	[au_view setFrame:NSMakeRect(xx, yy, req_width, req_height)];
 
+	NSArray* subviews = [au_view subviews];
+	for (unsigned long i = 0; i < [subviews count]; ++i) {
+		NSView* subview = [subviews objectAtIndex:i];
+		[subview setFrame:NSMakeRect (0, 0, req_width, req_height)];
+	}
+
 	last_au_frame = [au_view frame];
 	// watch for size changes of the view
 	_notify = [ [NotificationObject alloc] initWithPluginUI:this andCocoaParent:NULL andTopLevelParent:win ];
