@@ -110,6 +110,9 @@ LoudnessDialog::LoudnessDialog (Session* s, AudioRange const& ar, bool as)
 	, _ignore_preset (false)
 	, _ignore_change (false)
 {
+	/* Dialog can be displayed from the mixer, override global transient_parent */
+	unset_transient_for ();
+
 	/* query initial gain */
 	_gain_out = accurate_coefficient_to_dB (_session->master_volume()->get_value());
 
@@ -239,10 +242,10 @@ LoudnessDialog::LoudnessDialog (Session* s, AudioRange const& ar, bool as)
 
 	set_tooltip (_custom_pos_button,
 		_("<b>When enabled</b> an amplifier processor is used to apply the gain. "
-		  "This allows for custom positoning of the gain-stage in the master-bus' signal flow, "
+		  "This allows for custom positioning of the gain-stage in the master-bus' signal flow, "
 		  "potentially followed by a limiter to conform to both loudness and peak requirements. "
 		  "Depending on limiter settings or DSP after the gain-stage, repeat loudness measurements may produce different results.\n"
-		  "<b>When disabled</b>, the gain is applied diretcly to the output of the master-bus. This results in an efficient and reliable volume adjustment."
+		  "<b>When disabled</b>, the gain is applied directly to the output of the master-bus. This results in an efficient and reliable volume adjustment."
 		 ));
 
 	_dbfs_label.set_alignment (ALIGN_RIGHT);
@@ -499,13 +502,19 @@ LoudnessDialog::analyze ()
 
 	/* done */
   _status->finish (TRS_UI);
+
+	if (!_status->aborted() && _status->result_map.size () != 1) {
+		ArdourMessageDialog (_("Loudness measurement returned no results. Likely because the analyzed range is to short."), false, MESSAGE_ERROR).run ();
+		return 1;
+	}
+
   return _status->aborted() ? 1 : 0;
 }
 
 void
 LoudnessDialog::display_report ()
 {
-	ExportReport er ("Export Loudness Report", _status->result_map);
+	ExportReport er (_("Export Loudness Report"), _status->result_map);
 	er.set_transient_for (*this);
 	er.run();
 }
@@ -576,6 +585,12 @@ LoudnessDialog::display_results ()
 	assert (ar.size () == 1);
 	ExportAnalysisPtr p = ar.begin()->second;
 
+	if (!p->have_loudness || !p->have_dbtp) {
+		ArdourMessageDialog (
+				string_compose (_("True-peak and loudness measurement failed. %1-VAMP analysis plugin is missing on your system. Please contact your vendor."), PROGRAM_NAME),
+				false, MESSAGE_ERROR).run ();
+	}
+
 	_dbfs   = accurate_coefficient_to_dB (p->peak);
 	_dbtp   = accurate_coefficient_to_dB (p->truepeak);
 	_lufs_i = p->integrated_loudness    > -200  ? p->integrated_loudness    : -std::numeric_limits<float>::infinity();
