@@ -317,7 +317,7 @@ public:
 
 	RouteList get_routelist (bool mixer_order = false, PresentationInfo::Flag fl = PresentationInfo::MixerRoutes) const;
 
-	CoreSelection& selection () { return *_selection; }
+	CoreSelection& selection () const { return *_selection; }
 
 	/* because the set of Stripables consists of objects managed
 	 * independently, in multiple containers within the Session (or objects
@@ -1328,6 +1328,7 @@ private:
 	mutable gint            _record_status;
 	samplepos_t             _transport_sample;
 	gint                    _seek_counter;
+	gint                    _butler_seek_counter;
 	Location*               _session_range_location; ///< session range, or 0 if there is nothing in the session yet
 	bool                    _session_range_is_free;
 	bool                    _silent;
@@ -2023,6 +2024,8 @@ private:
 	samplecnt_t                   click_length;
 	samplecnt_t                   click_emphasis_length;
 	mutable Glib::Threads::RWLock click_lock;
+	samplecnt_t                  _click_io_latency;
+	PBD::ScopedConnection        _click_io_connection;
 
 	static const Sample     default_click[];
 	static const samplecnt_t default_click_length;
@@ -2038,6 +2041,7 @@ private:
 	void click (samplepos_t start, samplecnt_t nframes);
 	void run_click (samplepos_t start, samplecnt_t nframes);
 	void add_click (samplepos_t pos, bool emphasis);
+	void click_io_resync_latency (bool);
 
 	/* range playback */
 
