@@ -1643,12 +1643,28 @@ DiskReader::Declicker::~Declicker ()
 }
 
 void
-DiskReader::Declicker::alloc (samplecnt_t sr, bool fadein)
+DiskReader::Declicker::alloc (samplecnt_t sr, bool fadein, bool linear)
 {
 	delete[] vec;
 	vec = new Sample[loop_fade_length];
 
-	const float a = 390.0f / sr; // ~ 1/100Hz for 40dB
+	if (linear) {
+		if (fadein) {
+			for (samplecnt_t n = 0; n < loop_fade_length; ++n) {
+				vec[n] = n / (float) loop_fade_length;
+			}
+		} else {
+			for (samplecnt_t n = 0; n < loop_fade_length; ++n) {
+				vec[n] = 1.f - n / (float) loop_fade_length;
+			}
+		}
+		fade_length = loop_fade_length - 1;
+		return;
+	}
+
+	/* Exponential fade */
+
+	const float a = 390.f / sr; // ~ 1/100Hz for 40dB
 
 	/* build a psuedo-exponential (linear-volume) shape for the fade */
 
@@ -1668,13 +1684,20 @@ DiskReader::Declicker::alloc (samplecnt_t sr, bool fadein)
 		}
 	}
 
-	assert (n < loop_fade_length);
+	assert (n > 0 && n <= loop_fade_length);
 
-	fade_length = n;
+	fade_length = n - 1;
 
-	/* zero out the rest just to be safe */
-
-	memset (&vec[n], 0, sizeof (gain_t) * (loop_fade_length - n));
+	/* Fill remaining fader-buffer with the target value.
+	 *
+	 * This is needed for loop x-fade. Due to float precision near 1.0, fade-in length
+	 * is can be one or two samples shorter than fade-out length (depending on sample-rate).
+	 * Summing the fade-in and fade-out curve over the complete fade-range (fade-out,
+	 * as done by DiskReader::maybe_xfade_loop) must yield 1.0 +/- GAIN_COEFF_DELTA.
+	 */
+	for (; n < loop_fade_length; ++n) {
+		vec[n] = fadein ? 1.f : 0.f;
+	}
 }
 
 void
@@ -1877,8 +1900,8 @@ void
 DiskReader::alloc_loop_declick (samplecnt_t sr)
 {
 	loop_fade_length = lrintf (ceil (-log (GAIN_COEFF_DELTA / 2.) / (390. / sr)));
-	loop_declick_in.alloc (sr, true);
-	loop_declick_out.alloc (sr, false);
+	loop_declick_in.alloc (sr, true, Config->get_loop_fade_choice () == XFadeLoop);
+	loop_declick_out.alloc (sr, false, Config->get_loop_fade_choice () == XFadeLoop);
 }
 
 #undef GAIN_COEFF_DELTA
