@@ -134,8 +134,8 @@ ExportFormatSpecification::Time::set_state (const XMLNode & node)
 
 ExportFormatSpecification::ExportFormatSpecification (Session & s)
 	: session (s)
-	, has_sample_format (false)
-	, supports_tagging (false)
+	, _has_sample_format (false)
+	, _supports_tagging (false)
 	, _has_codec_quality (false)
 	, _has_broadcast_info (false)
 	, _channel_limit (0)
@@ -173,8 +173,8 @@ ExportFormatSpecification::ExportFormatSpecification (Session & s)
 
 ExportFormatSpecification::ExportFormatSpecification (Session & s, XMLNode const & state)
 	: session (s)
-	, has_sample_format (false)
-	, supports_tagging (false)
+	, _has_sample_format (false)
+	, _supports_tagging (false)
 	, _has_codec_quality (false)
 	, _has_broadcast_info (false)
 	, _channel_limit (0)
@@ -232,8 +232,8 @@ ExportFormatSpecification::ExportFormatSpecification (ExportFormatSpecification
 	}
 
 	_format_name = other._format_name;
-	has_sample_format = other.has_sample_format;
-	supports_tagging = other.supports_tagging;
+	_has_sample_format = other._has_sample_format;
+	_supports_tagging = other._supports_tagging;
 	_has_codec_quality = other._has_codec_quality;
 	_has_broadcast_info = other._has_broadcast_info;
 	_channel_limit = other._channel_limit;
@@ -287,7 +287,7 @@ ExportFormatSpecification::get_state ()
 	node->set_property ("type", type());
 	node->set_property ("extension", extension());
 	node->set_property ("name", _format_name);
-	node->set_property ("has-sample-format", has_sample_format);
+	node->set_property ("has-sample-format", _has_sample_format);
 	node->set_property ("channel-limit", _channel_limit);
 
 	node = root->add_child ("SampleRate");
@@ -311,7 +311,7 @@ ExportFormatSpecification::get_state ()
 	add_option (enc_opts, "sample-format", to_string(sample_format()));
 	add_option (enc_opts, "dithering", to_string (dither_type()));
 	add_option (enc_opts, "tag-metadata", to_string (_tag));
-	add_option (enc_opts, "tag-support", to_string (supports_tagging));
+	add_option (enc_opts, "tag-support", to_string (_supports_tagging));
 	add_option (enc_opts, "broadcast-info", to_string (_has_broadcast_info));
 
 	XMLNode * processing = root->add_child ("Processing");
@@ -398,7 +398,7 @@ ExportFormatSpecification::set_state (const XMLNode & root)
 		}
 
 		child->get_property ("name", _format_name);
-		child->get_property ("has-sample-format", has_sample_format);
+		child->get_property ("has-sample-format", _has_sample_format);
 		child->get_property ("channel-limit", _channel_limit);
 	}
 
@@ -447,7 +447,7 @@ ExportFormatSpecification::set_state (const XMLNode & root)
 		set_sample_format ((SampleFormat) string_2_enum (get_option (child, "sample-format"), SampleFormat));
 		set_dither_type ((DitherType) string_2_enum (get_option (child, "dithering"), DitherType));
 		set_tag (string_to<bool>(get_option (child, "tag-metadata")));
-		supports_tagging = string_to<bool>(get_option (child, "tag-support"));
+		_supports_tagging = string_to<bool>(get_option (child, "tag-support"));
 		_has_broadcast_info = string_to<bool>(get_option (child, "broadcast-info"));
 	}
 
@@ -552,7 +552,7 @@ ExportFormatSpecification::is_complete () const
 		return false;
 	}
 
-	if (has_sample_format) {
+	if (_has_sample_format) {
 		if (sample_format() == SF_None) {
 			return false;
 		}
@@ -577,7 +577,7 @@ ExportFormatSpecification::set_format (boost::shared_ptr<ExportFormat> format)
 		}
 
 		if (format->has_sample_format()) {
-			has_sample_format = true;
+			_has_sample_format = true;
 		}
 
 		if (format->has_broadcast_info()) {
@@ -591,7 +591,7 @@ ExportFormatSpecification::set_format (boost::shared_ptr<ExportFormat> format)
 			_codec_quality = boost::dynamic_pointer_cast<HasCodecQuality> (format)->default_codec_quality();
 		}
 
-		supports_tagging = format->supports_tagging ();
+		_supports_tagging = format->supports_tagging ();
 		_channel_limit = format->get_channel_limit();
 
 		_format_name = format->name();
@@ -600,8 +600,8 @@ ExportFormatSpecification::set_format (boost::shared_ptr<ExportFormat> format)
 		set_type (T_None);
 		set_extension ("");
 		_has_broadcast_info = false;
-		has_sample_format = false;
-		supports_tagging = false;
+		_has_sample_format = false;
+		_supports_tagging = false;
 		_channel_limit = 0;
 		_codec_quality = 0;
 		_format_name = "";
@@ -633,7 +633,7 @@ ExportFormatSpecification::description (bool include_name)
 		components.push_back (_format_name);
 	}
 
-	if (has_sample_format) {
+	if (_has_sample_format) {
 		components.push_back (HasSampleFormat::get_sample_format_name (sample_format()));
 	}
 
