@@ -25,8 +25,10 @@
 #include "pbd/failed_constructor.h"
 
 #include "ardour/analyser.h"
+#include "ardour/audioengine.h"
 #include "ardour/audiofilesource.h"
 #include "ardour/audiosource.h"
+#include "ardour/internal_send.h"
 #include "ardour/lua_api.h"
 #include "ardour/luaproc.h"
 #include "ardour/luascripting.h"
@@ -125,12 +127,13 @@ ARDOUR::LuaAPI::list_plugins ()
 #ifdef LXVST_SUPPORT
 	all_plugs.insert (all_plugs.end (), manager.lxvst_plugin_info ().begin (), manager.lxvst_plugin_info ().end ());
 #endif
+#ifdef VST3_SUPPORT
+	all_plugs.insert (all_plugs.end (), manager.vst3_plugin_info ().begin (), manager.vst3_plugin_info ().end ());
+#endif
 #ifdef AUDIOUNIT_SUPPORT
 	all_plugs.insert (all_plugs.end (), manager.au_plugin_info ().begin (), manager.au_plugin_info ().end ());
 #endif
-#ifdef LV2_SUPPORT
 	all_plugs.insert (all_plugs.end (), manager.lv2_plugin_info ().begin (), manager.lv2_plugin_info ().end ());
-#endif
 	all_plugs.insert (all_plugs.end (), manager.lua_plugin_info ().begin (), manager.lua_plugin_info ().end ());
 
 	return all_plugs;
@@ -152,12 +155,13 @@ ARDOUR::LuaAPI::new_plugin_info (const string& name, ARDOUR::PluginType type)
 #ifdef LXVST_SUPPORT
 	all_plugs.insert (all_plugs.end (), manager.lxvst_plugin_info ().begin (), manager.lxvst_plugin_info ().end ());
 #endif
+#ifdef VST3_SUPPORT
+	all_plugs.insert (all_plugs.end (), manager.vst3_plugin_info ().begin (), manager.vst3_plugin_info ().end ());
+#endif
 #ifdef AUDIOUNIT_SUPPORT
 	all_plugs.insert (all_plugs.end (), manager.au_plugin_info ().begin (), manager.au_plugin_info ().end ());
 #endif
-#ifdef LV2_SUPPORT
 	all_plugs.insert (all_plugs.end (), manager.lv2_plugin_info ().begin (), manager.lv2_plugin_info ().end ());
-#endif
 	all_plugs.insert (all_plugs.end (), manager.lua_plugin_info ().begin (), manager.lua_plugin_info ().end ());
 
 	for (PluginInfoList::const_iterator i = all_plugs.begin (); i != all_plugs.end (); ++i) {
@@ -422,6 +426,46 @@ ARDOUR::LuaAPI::timecode_to_sample_lua (lua_State *L)
 	return 1;
 }
 
+
+static
+void proc_cycle_start (size_t* cnt)
+{
+	++*cnt;
+}
+
+bool
+ARDOUR::LuaAPI::wait_for_process_callback (size_t n_cycles, int64_t timeout_ms)
+{
+	if (!AudioEngine::instance()->running()) {
+		return false;
+	}
+#if 0
+	if (AudioEngine::instance()->freewheeling()) {
+		return false;
+	}
+#endif
+	if (AudioEngine::instance()->measuring_latency() != AudioEngine::MeasureNone) {
+		return false;
+	}
+	if (!AudioEngine::instance()->session() ) {
+		return false;
+	}
+
+	size_t cnt = 0;
+	ScopedConnection c;
+
+	InternalSend::CycleStart.connect_same_thread (c, boost::bind (&proc_cycle_start, &cnt));
+	while (cnt <= n_cycles) {
+		Glib::usleep (1000);
+		if (timeout_ms > 0) {
+			if (--timeout_ms == 0) {
+				return cnt > n_cycles;
+			}
+		}
+	}
+	return true;
+}
+
 int
 ARDOUR::LuaOSC::Address::send (lua_State *L)
 {
