@@ -186,6 +186,7 @@ void
 LuaProc::drop_references ()
 {
 	lua.collect_garbage ();
+	Plugin::drop_references ();
 }
 
 boost::weak_ptr<Route>
@@ -393,9 +394,12 @@ LuaProc::load_script ()
 }
 
 bool
-LuaProc::can_support_io_configuration (const ChanCount& in, ChanCount& out, ChanCount* imprecise)
+LuaProc::match_variable_io (ChanCount& in, ChanCount& aux_in, ChanCount& out)
 {
-	// caller must hold process lock (no concurrent calls to interpreter
+	/* Lua does not have dedicated sidechain busses */
+	in += aux_in;
+
+	/* caller must hold process lock (no concurrent calls to interpreter */
 	_output_configs.clear ();
 
 	lua_State* L = lua.getState ();
@@ -444,50 +448,44 @@ LuaProc::can_support_io_configuration (const ChanCount& in, ChanCount& out, Chan
 	float penalty = 9999;
 	bool found = false;
 
-#define FOUNDCFG_PENALTY(in, out, p) {                              \
-  _output_configs.insert (out);                                     \
-  if (p < penalty) {                                                \
-    audio_out = (out);                                              \
-    midi_out = possible_midiout;                                    \
-    if (imprecise) {                                                \
-      imprecise->set (DataType::AUDIO, (in));                       \
-      imprecise->set (DataType::MIDI, possible_midiin);             \
-    }                                                               \
-    _has_midi_input = (possible_midiin > 0);                        \
-    _has_midi_output = (possible_midiout > 0);                      \
-    penalty = p;                                                    \
-    found = true;                                                   \
-  }                                                                 \
+#define FOUNDCFG_PENALTY(n_in, n_out, p) {     \
+  _output_configs.insert (n_out);              \
+  if (p < penalty) {                           \
+    audio_out = (n_out);                       \
+    midi_out = possible_midiout;               \
+    in.set (DataType::AUDIO, (n_in));          \
+    in.set (DataType::MIDI, possible_midiin);  \
+    _has_midi_input = (possible_midiin > 0);   \
+    _has_midi_output = (possible_midiout > 0); \
+    penalty = p;                               \
+    found = true;                              \
+  }                                            \
 }
 
-#define FOUNDCFG_IMPRECISE(in, out) {                               \
-  const float p = fabsf ((float)(out) - preferred_out) *            \
-                      (((out) > preferred_out) ? 1.1 : 1)           \
+#define FOUNDCFG_IMPRECISE(n_in, n_out) {                                  \
+  const float p = fabsf ((float)(n_out) - preferred_out) *                 \
+                      (((n_out) > preferred_out) ? 1.1 : 1)                \
                 + fabsf ((float)possible_midiout - preferred_midiout) *    \
                       ((possible_midiout - preferred_midiout) ? 0.6 : 0.5) \
-                + fabsf ((float)(in) - audio_in) *                  \
-                      (((in) > audio_in) ? 275 : 250)               \
-                + fabsf ((float)possible_midiin - midi_in) *        \
-                      ((possible_midiin - midi_in) ? 100 : 110);    \
-  FOUNDCFG_PENALTY(in, out, p);                                     \
+                + fabsf ((float)(n_in) - audio_in) *                       \
+                      (((n_in) > audio_in) ? 275 : 250)                    \
+                + fabsf ((float)possible_midiin - midi_in) *               \
+                      ((possible_midiin - midi_in) ? 100 : 110);           \
+  FOUNDCFG_PENALTY(n_in, n_out, p);                                        \
 }
 
-#define FOUNDCFG(out)                                               \
-  FOUNDCFG_IMPRECISE(audio_in, out)
+#define FOUNDCFG(n_out)              \
+  FOUNDCFG_IMPRECISE(audio_in, n_out)
 
-#define ANYTHINGGOES                                                \
+#define ANYTHINGGOES          \
   _output_configs.insert (0);
 
-#define UPTO(nch) {                                                 \
-  for (int n = 1; n < nch; ++n) {                                   \
-    _output_configs.insert (n);                                     \
-  }                                                                 \
+#define UPTO(nch) {               \
+  for (int n = 1; n < nch; ++n) { \
+    _output_configs.insert (n);   \
+  }                               \
 }
 
-	if (imprecise) {
-		*imprecise = in;
-	}
-
 	for (luabridge::Iterator i (iotable); !i.isNil (); ++i) {
 		luabridge::LuaRef io (i.value ());
 		if (!io.isTable()) {
@@ -499,10 +497,6 @@ LuaProc::can_support_io_configuration (const ChanCount& in, ChanCount& out, Chan
 		int possible_midiin = io["midi_in"].isNumber() ? io["midi_in"] : 0;
 		int possible_midiout = io["midi_out"].isNumber() ? io["midi_out"] : 0;
 
-		if (midi_in != possible_midiin && !imprecise) {
-			continue;
-		}
-
 		// exact match
 		if ((possible_in == audio_in) && (possible_out == preferred_out)) {
 			/* Set penalty so low that this output configuration
@@ -547,11 +541,7 @@ LuaProc::can_support_io_configuration (const ChanCount& in, ChanCount& out, Chan
 				/* configuration can match up to -possible_in */
 				desired_in = std::min (-possible_in, audio_in);
 			}
-			if (!imprecise && audio_in != desired_in) {
-				/* skip that configuration, it cannot match
-				 * the required audio input count, and we
-				 * cannot ask for change via \imprecise */
-			} else if (possible_out == -1 || possible_out == -2) {
+			if (possible_out == -1 || possible_out == -2) {
 				/* any output configuration possible
 				 * out == -2 is invalid, interpreted as out == -1.
 				 * Really imprecise only if desired_in != audio_in */
@@ -576,27 +566,29 @@ LuaProc::can_support_io_configuration (const ChanCount& in, ChanCount& out, Chan
 		return false;
 	}
 
-	if (imprecise) {
-		_selected_in = *imprecise;
-	} else {
-		_selected_in = in;
-	}
-
 	out.set (DataType::MIDI, midi_out);
 	out.set (DataType::AUDIO, audio_out);
+
+	_selected_in = in; // TODO remove after testing
 	_selected_out = out;
 
+	/* restore side-chain input count */
+	in -= aux_in;
+
 	return true;
 }
 
 bool
-LuaProc::configure_io (ChanCount in, ChanCount out)
+LuaProc::reconfigure_io (ChanCount in, ChanCount aux_in, ChanCount out)
 {
+	in += aux_in;
+	assert (in == _selected_in && out ==_selected_out);
+
 	in.set (DataType::MIDI, _has_midi_input ? 1 : 0);
 	out.set (DataType::MIDI, _has_midi_output ? 1 : 0);
 
-	_info->n_inputs = _selected_in;
-	_info->n_outputs = _selected_out;
+	_info->n_inputs = in;
+	_info->n_outputs = out;
 
 	// configure the DSP if needed
 	if (in != _configured_in || out != _configured_out || !_configured) {
@@ -606,8 +598,8 @@ LuaProc::configure_io (ChanCount in, ChanCount out)
 			try {
 				luabridge::LuaRef io = lua_dsp_configure (in, out);
 				if (io.isTable ()) {
-					ChanCount lin (_selected_in);
-					ChanCount lout (_selected_out);
+					ChanCount lin (in);
+					ChanCount lout (out);
 
 					if (io["audio_in"].type() == LUA_TNUMBER) {
 						const int c = io["audio_in"].cast<int> ();
@@ -776,7 +768,7 @@ LuaProc::connect_and_run (BufferSet& bufs,
 							data[size] = di.value ();
 						}
 						if (size > 0 && size < 64) {
-							mbuf.push_back(tme - 1, size, data);
+							mbuf.push_back(tme - 1, Evoral::MIDI_EVENT, size, data);
 						}
 					}
 
@@ -916,7 +908,7 @@ LuaProc::set_state (const XMLNode& node, int version)
 			continue;
 		}
 
-		set_parameter (port_id, value);
+		set_parameter (port_id, value, 0);
 	}
 
 	return Plugin::set_state (node, version);
@@ -940,14 +932,14 @@ LuaProc::default_value (uint32_t port)
 }
 
 void
-LuaProc::set_parameter (uint32_t port, float val)
+LuaProc::set_parameter (uint32_t port, float val, sampleoffset_t when)
 {
 	assert (port < parameter_count ());
 	if (get_parameter (port) == val) {
 		return;
 	}
 	_shadow_data[port] = val;
-	Plugin::set_parameter (port, val);
+	Plugin::set_parameter (port, val, when);
 }
 
 float
@@ -1176,7 +1168,7 @@ LuaProc::load_preset (PresetRecord r)
 					assert (false);
 					continue;
 				}
-				set_parameter (index, value);
+				set_parameter (index, value, 0);
 				PresetPortSetValue (index, value); /* EMIT SIGNAL */
 			}
 		}
@@ -1269,7 +1261,7 @@ LuaPluginInfo::LuaPluginInfo (LuaScriptInfoPtr lsi) {
 	n_outputs.set (DataType::AUDIO, 1);
 	type = Lua;
 
-	// TODO, parse script, get 'dsp_ioconfig', see can_support_io_configuration()
+	// TODO, parse script, get 'dsp_ioconfig', see match_variable_io()
 	_max_outputs = 0;
 }
 
