@@ -40,6 +40,12 @@
 #include <lrdf.h>
 #endif
 
+#if defined PLATFORM_WINDOWS && defined VST3_SUPPORT
+#include <windows.h>
+#include <shlobj.h> // CSIDL_*
+#include "pbd/windows_special_dirs.h"
+#endif
+
 #ifdef WINDOWS_VST_SUPPORT
 #include "ardour/vst_info_file.h"
 #include "fst.h"
@@ -73,7 +79,6 @@
 #include <glibmm/miscutils.h>
 #include <glibmm/pattern.h>
 #include <glibmm/fileutils.h>
-#include <glibmm/miscutils.h>
 
 #include "pbd/convert.h"
 #include "pbd/file_utils.h"
@@ -87,15 +92,13 @@
 #include "ardour/ladspa_plugin.h"
 #include "ardour/luascripting.h"
 #include "ardour/luaproc.h"
+#include "ardour/lv2_plugin.h"
 #include "ardour/plugin.h"
 #include "ardour/plugin_manager.h"
 #include "ardour/rc_configuration.h"
 
 #include "ardour/search_paths.h"
 
-#ifdef LV2_SUPPORT
-#include "ardour/lv2_plugin.h"
-#endif
 
 #ifdef WINDOWS_VST_SUPPORT
 #include "ardour/windows_vst_plugin.h"
@@ -110,6 +113,13 @@
 #include <Carbon/Carbon.h>
 #endif
 
+#ifdef VST3_SUPPORT
+#include "ardour/system_exec.h"
+#include "ardour/vst3_module.h"
+#include "ardour/vst3_plugin.h"
+#include "ardour/vst3_scan.h"
+#endif
+
 #include "pbd/error.h"
 #include "pbd/stl_delete.h"
 
@@ -123,6 +133,22 @@ using namespace std;
 
 PluginManager* PluginManager::_instance = 0;
 std::string PluginManager::scanner_bin_path = "";
+std::string PluginManager::vst3_scanner_bin_path = "";
+
+
+#ifdef VST3_SUPPORT
+# if defined __x86_64__ || defined _M_X64
+#  define VST3_BLACKLIST  "vst3_x64_blacklist.txt"
+# elif defined __i386__  || defined _M_IX86
+#  define VST3_BLACKLIST  "vst3_x86_blacklist.txt"
+# elif defined __aarch64__
+#  define VST3_BLACKLIST  "vst3_a64_blacklist.txt"
+# elif defined __arm__
+#  define VST3_BLACKLIST  "vst3_a32_blacklist.txt"
+# else
+#  define VST3_BLACKLIST  "vst3_blacklist.txt"
+# endif
+#endif
 
 PluginManager&
 PluginManager::instance()
@@ -137,6 +163,7 @@ PluginManager::PluginManager ()
 	: _windows_vst_plugin_info(0)
 	, _lxvst_plugin_info(0)
 	, _mac_vst_plugin_info(0)
+	, _vst3_plugin_info(0)
 	, _ladspa_plugin_info(0)
 	, _lv2_plugin_info(0)
 	, _au_plugin_info(0)
@@ -147,7 +174,7 @@ PluginManager::PluginManager ()
 	char* s;
 	string lrdf_path;
 
-#if defined WINDOWS_VST_SUPPORT || defined LXVST_SUPPORT || defined MACVST_SUPPORT
+#if defined WINDOWS_VST_SUPPORT || defined LXVST_SUPPORT || defined MACVST_SUPPORT || defined VST3_SUPPORT
 	// source-tree (ardev, etc)
 	PBD::Searchpath vstsp(Glib::build_filename(ARDOUR::ardour_dll_directory(), "fst"));
 
@@ -159,6 +186,7 @@ PluginManager::PluginManager ()
 	vstsp += ARDOUR::ardour_dll_directory();
 #endif
 
+#if defined WINDOWS_VST_SUPPORT || defined LXVST_SUPPORT || defined MACVST_SUPPORT
 	if (!PBD::find_file (vstsp,
 #ifdef PLATFORM_WINDOWS
     #ifdef DEBUGGABLE_SCANNER_APP
@@ -176,7 +204,28 @@ PluginManager::PluginManager ()
 				, scanner_bin_path)) {
 		PBD::warning << "VST scanner app (ardour-vst-scanner) not found in path " << vstsp.to_string() << endmsg;
 	}
+#endif // VST2
+
+#ifdef VST3_SUPPORT
+	if (!PBD::find_file (vstsp,
+#ifdef PLATFORM_WINDOWS
+    #ifdef DEBUGGABLE_SCANNER_APP
+        #if defined(DEBUG) || defined(_DEBUG)
+				"ardour-vst3-scannerD.exe"
+        #else
+				"ardour-vst3-scannerRDC.exe"
+        #endif
+    #else
+				"ardour-vst3-scanner.exe"
+    #endif
+#else
+				"ardour-vst3-scanner"
 #endif
+				, vst3_scanner_bin_path)) {
+		PBD::warning << "VST3 scanner app (ardour-vst3-scanner) not found in path " << vstsp.to_string() << endmsg;
+	}
+#endif // VST3_SUPPORT
+#endif // any VST
 
 	load_statuses ();
 	load_tags ();
@@ -239,6 +288,14 @@ PluginManager::PluginManager ()
 	if (Config->get_plugin_path_vst() == X_("@default@")) {
 		Config->set_plugin_path_vst(get_default_windows_vst_path());
 	}
+	if (Config->get_plugin_path_vst3() == X_("@default@")) {
+		/* This path is currently only added to the existing path */
+		if ((s = getenv ("VST3_PATH"))) {
+			Config->set_plugin_path_vst3 (s);
+		} else {
+			Config->set_plugin_path_vst3 ("");
+		}
+	}
 
 	if (_instance == 0) {
 		_instance = this;
@@ -257,6 +314,7 @@ PluginManager::~PluginManager()
 		delete _windows_vst_plugin_info;
 		delete _lxvst_plugin_info;
 		delete _mac_vst_plugin_info;
+		delete _vst3_plugin_info;
 		delete _ladspa_plugin_info;
 		delete _lv2_plugin_info;
 		delete _au_plugin_info;
@@ -281,7 +339,7 @@ PluginManager::detect_name_ambiguities (PluginInfoList* pil)
 	for (PluginInfoList::iterator i = pil->begin(); i != pil->end();) {
 		 PluginInfoPtr& p = *i;
 		 ++i;
-		 if (i != pil->end() && (*i)->name == p->name) {
+		 if (i != pil->end() && PBD::downcase ((*i)->name) == PBD::downcase (p->name)) {
 			 /* mark name as ambiguous IFF ambiguity can be resolved
 				* by listing number of audio outputs.
 				* This is used in the instrument selector.
@@ -303,12 +361,12 @@ PluginManager::detect_type_ambiguities (PluginInfoList& pil)
 			case 0:
 				break;
 			case 1:
-				if (dup.back()->name != (*i)->name) {
+				if (PBD::downcase (dup.back()->name) != PBD::downcase ((*i)->name)) {
 					dup.clear ();
 				}
 				break;
 			default:
-				if (dup.back()->name != (*i)->name) {
+				if (PBD::downcase (dup.back()->name) != PBD::downcase ((*i)->name)) {
 					/* found multiple plugins with same name */
 					bool typediff = false;
 					bool chandiff = false;
@@ -337,6 +395,25 @@ PluginManager::detect_type_ambiguities (PluginInfoList& pil)
 	}
 }
 
+void
+PluginManager::conceal_duplicates (ARDOUR::PluginInfoList* old, ARDOUR::PluginInfoList* nu)
+{
+	if (!old) {
+		return;
+	}
+	for (PluginInfoList::const_iterator i = old->begin(); i != old->end(); ++i) {
+		for (PluginInfoList::const_iterator j = nu->begin(); j != nu->end(); ++j) {
+			if ((*i)->creator == (*j)->creator && (*i)->name == (*j)->name) {
+				PluginStatus ps ((*i)->type, (*i)->unique_id, Concealed);
+				if (find (statuses.begin(), statuses.end(), ps) == statuses.end()) {
+					statuses.erase (ps);
+					statuses.insert (ps);
+				}
+			}
+		}
+	}
+}
+
 void
 PluginManager::refresh (bool cache_only)
 {
@@ -353,31 +430,16 @@ PluginManager::refresh (bool cache_only)
 	ladspa_refresh ();
 	BootMessage (_("Scanning Lua DSP Processors"));
 	lua_refresh ();
-#ifdef LV2_SUPPORT
+
 	BootMessage (_("Scanning LV2 Plugins"));
 	lv2_refresh ();
 
-	if (Config->get_conceal_lv1_if_lv2_exists()) {
-		for (PluginInfoList::const_iterator i = _ladspa_plugin_info->begin(); i != _ladspa_plugin_info->end(); ++i) {
-			for (PluginInfoList::const_iterator j = _lv2_plugin_info->begin(); j != _lv2_plugin_info->end(); ++j) {
-				if ((*i)->creator == (*j)->creator && (*i)->name == (*j)->name) {
-					PluginStatus ps (LADSPA, (*i)->unique_id, Concealed);
-					if (find (statuses.begin(), statuses.end(), ps) == statuses.end()) {
-						statuses.erase (ps);
-						statuses.insert (ps);
-					}
-				}
-			}
-		}
-	} else {
-		for (PluginStatusList::iterator i = statuses.begin(); i != statuses.end();) {
-			PluginStatusList::iterator j = i++;
-			if ((*j).status == Concealed) {
-				statuses.erase (j);
-			}
-		}
+	bool conceal_lv1 = Config->get_conceal_lv1_if_lv2_exists();
+
+	if (conceal_lv1) {
+		conceal_duplicates (_ladspa_plugin_info, _lv2_plugin_info);
 	}
-#endif
+
 #ifdef WINDOWS_VST_SUPPORT
 	if (Config->get_use_windows_vst()) {
 		if (cache_only) {
@@ -416,20 +478,44 @@ PluginManager::refresh (bool cache_only)
 #endif //Native Mac VST SUPPORT
 
 #if (defined WINDOWS_VST_SUPPORT || defined LXVST_SUPPORT || defined MACVST_SUPPORT)
-		if (!cache_only) {
-			string fn = Glib::build_filename (ARDOUR::user_cache_directory(), VST_BLACKLIST);
-			if (Glib::file_test (fn, Glib::FILE_TEST_EXISTS)) {
-				gchar *bl = NULL;
-				if (g_file_get_contents(fn.c_str (), &bl, NULL, NULL)) {
-					if (Config->get_verbose_plugin_scan()) {
-						PBD::info << _("VST Blacklist: ") << fn << "\n" << bl << "-----" << endmsg;
-					} else {
-						PBD::info << _("VST Blacklist:") << "\n" << bl << "-----" << endmsg;
-					}
-					g_free (bl);
-				}
+	if (!cache_only) {
+		string fn = Glib::build_filename (ARDOUR::user_cache_directory(), VST_BLACKLIST);
+		if (Glib::file_test (fn, Glib::FILE_TEST_EXISTS)) {
+			try {
+				std::string bl = Glib::file_get_contents (fn);
+				PBD::info << _("VST 2 Blacklist: ") << "\n" << bl << "-----" << endmsg;
+			} catch (Glib::FileError const& err) {
 			}
 		}
+	}
+#endif
+
+#ifdef VST3_SUPPORT
+	if (cache_only) {
+		BootMessage (_("Scanning VST3 Plugins"));
+	} else {
+		BootMessage (_("Discovering VST3 Plugins"));
+	}
+	vst3_refresh (cache_only);
+
+	if (!cache_only) {
+		string fn = Glib::build_filename (ARDOUR::user_cache_directory (), VST3_BLACKLIST);
+		if (Glib::file_test (fn, Glib::FILE_TEST_EXISTS)) {
+			try {
+				std::string bl = Glib::file_get_contents (fn);
+				PBD::info << _("VST 3 Blacklist: ") << "\n" << bl << "-----" << endmsg;
+			} catch (Glib::FileError const& err) {
+			}
+		}
+	}
+	bool conceal_vst2 = Config->get_conceal_vst2_if_vst3_exists();
+	if (conceal_vst2) {
+		conceal_duplicates (_windows_vst_plugin_info, _vst3_plugin_info);
+		conceal_duplicates (_lxvst_plugin_info, _vst3_plugin_info);
+		conceal_duplicates (_mac_vst_plugin_info, _vst3_plugin_info);
+	}
+#else
+	bool conceal_vst2 = false;
 #endif
 
 #ifdef AUDIOUNIT_SUPPORT
@@ -441,6 +527,22 @@ PluginManager::refresh (bool cache_only)
 	au_refresh (cache_only);
 #endif
 
+	/* unset concealed plugins */
+	if (!conceal_lv1 || !conceal_vst2) {
+		for (PluginStatusList::iterator i = statuses.begin(); i != statuses.end();) {
+			PluginStatusList::iterator j = i++;
+			if ((*j).status != Concealed) {
+				continue;
+			}
+			if (!conceal_lv1 && (*j).type == LADSPA) {
+				statuses.erase (j);
+			}
+			if (!conceal_vst2 && ((*j).type == Windows_VST || (*j).type == LXVST || (*j).type == MacVST)) {
+				statuses.erase (j);
+			}
+		}
+	}
+
 	BootMessage (_("Plugin Scan Complete..."));
 	PluginListChanged (); /* EMIT SIGNAL */
 	PluginScanMessage(X_("closeme"), "", false);
@@ -455,6 +557,7 @@ PluginManager::refresh (bool cache_only)
 	detect_name_ambiguities (_ladspa_plugin_info);
 	detect_name_ambiguities (_lv2_plugin_info);
 	detect_name_ambiguities (_lua_plugin_info);
+	detect_name_ambiguities (_vst3_plugin_info);
 
 	PluginInfoList all_plugs;
 	if (_windows_vst_plugin_info) {
@@ -466,6 +569,9 @@ PluginManager::refresh (bool cache_only)
 	if (_mac_vst_plugin_info) {
 		all_plugs.insert(all_plugs.end(), _mac_vst_plugin_info->begin(), _mac_vst_plugin_info->end());
 	}
+	if (_vst3_plugin_info) {
+		all_plugs.insert(all_plugs.end(), _vst3_plugin_info->begin(), _vst3_plugin_info->end());
+	}
 	if (_au_plugin_info) {
 		all_plugs.insert(all_plugs.end(), _au_plugin_info->begin(), _au_plugin_info->end());
 	}
@@ -944,7 +1050,6 @@ PluginManager::get_ladspa_category (uint32_t plugin_id)
 #endif
 }
 
-#ifdef LV2_SUPPORT
 void
 PluginManager::lv2_refresh ()
 {
@@ -956,7 +1061,6 @@ PluginManager::lv2_refresh ()
 		set_tags ((*i)->type, (*i)->unique_id, (*i)->category, (*i)->name, FromPlug);
 	}
 }
-#endif
 
 #ifdef AUDIOUNIT_SUPPORT
 void
@@ -1424,6 +1528,311 @@ PluginManager::lxvst_discover (string path, bool cache_only)
 
 #endif // LXVST_SUPPORT
 
+void
+PluginManager::clear_vst3_cache ()
+{
+#ifdef VST3_SUPPORT
+	string dn = Glib::build_filename (ARDOUR::user_cache_directory(), "vst");
+	vector<string> v3i_files;
+	find_files_matching_regex (v3i_files, dn, "\\.v3i$", false);
+	for (vector<string>::iterator i = v3i_files.begin(); i != v3i_files.end (); ++i) {
+		::g_unlink(i->c_str());
+	}
+#endif
+}
+
+void
+PluginManager::clear_vst3_blacklist ()
+{
+#ifdef VST3_SUPPORT
+	string fn = Glib::build_filename (ARDOUR::user_cache_directory (), VST3_BLACKLIST);
+	if (Glib::file_test (fn, Glib::FILE_TEST_EXISTS)) {
+		::g_unlink(fn.c_str());
+	}
+#endif
+}
+
+#ifdef VST3_SUPPORT
+
+static void vst3_blacklist (string const& module_path)
+{
+	string fn = Glib::build_filename (ARDOUR::user_cache_directory (), VST3_BLACKLIST);
+	FILE* f = NULL;
+	if (! (f = g_fopen (fn.c_str (), "a"))) {
+		PBD::error << string_compose (_("Cannot write to VST3 blacklist file '%1'"), fn) << endmsg;
+		return;
+	}
+	fprintf (f, "%s\n", module_path.c_str ());
+	::fclose (f);
+}
+
+static void vst3_whitelist (string module_path)
+{
+	string fn = Glib::build_filename (ARDOUR::user_cache_directory (), VST3_BLACKLIST);
+	if (!Glib::file_test (fn, Glib::FILE_TEST_EXISTS)) {
+		return;
+	}
+
+	std::string bl;
+	try {
+		bl = Glib::file_get_contents (fn);
+	} catch (Glib::FileError const& err) {
+		return;
+	}
+	::g_unlink (fn.c_str ());
+
+	module_path += "\n"; // add separator
+	const size_t rpl = bl.find (module_path);
+	if (rpl != string::npos) {
+		bl.replace (rpl, module_path.size (), "");
+	}
+	if (bl.empty ()) {
+		return;
+	}
+	Glib::file_set_contents (fn, bl);
+}
+
+static bool vst3_is_blacklisted (string const& module_path)
+{
+	string fn = Glib::build_filename (ARDOUR::user_cache_directory (), VST3_BLACKLIST);
+	if (!Glib::file_test (fn, Glib::FILE_TEST_EXISTS)) {
+		return false;
+	}
+
+	std::string bl;
+	try {
+		bl = Glib::file_get_contents (fn);
+	} catch (Glib::FileError const& err) {
+		return false;
+	}
+	return bl.find (module_path + "\n") != string::npos;
+}
+
+static bool vst3_filter (const string& str, void*)
+{
+	return str[0] != '.' && (str.length() > 4 && str.find (".vst3") == (str.length() - 5));
+}
+
+void
+PluginManager::vst3_refresh (bool cache_only)
+{
+	if (_vst3_plugin_info) {
+		_vst3_plugin_info->clear ();
+	} else {
+		_vst3_plugin_info = new ARDOUR::PluginInfoList();
+	}
+
+#ifdef __APPLE__
+	vst3_discover_from_path ("~/Library/Audio/Plug-Ins/VST3:/Library/Audio/Plug-Ins/VST3", cache_only);
+#elif defined PLATFORM_WINDOWS
+	std::string prog = PBD::get_win_special_folder_path (CSIDL_PROGRAM_FILES);
+	vst3_discover_from_path (Glib::build_filename (prog, "Common Files", "VST3"), cache_only);
+#else
+	vst3_discover_from_path ("~/.vst3:/usr/local/lib/vst3:/usr/lib/vst3", cache_only);
+#endif
+}
+
+int
+PluginManager::vst3_discover_from_path (string const& path, bool cache_only)
+{
+	if (Session::get_disable_all_loaded_plugins ()) {
+		info << _("Disabled VST3 scan (safe mode)") << endmsg;
+		return -1;
+	}
+
+	Searchpath paths (path);
+	if (!Config->get_plugin_path_vst3().empty ()) {
+		Searchpath custom (Config->get_plugin_path_vst3 ());
+		paths += custom;
+	}
+
+	DEBUG_TRACE (DEBUG::PluginManager, string_compose ("VST3: search along: [%1]\n", paths.to_string ()));
+
+	vector<string> plugin_objects;
+
+	find_paths_matching_filter (plugin_objects, paths, vst3_filter, 0, false, true, true);
+
+	for (vector<string>::iterator i = plugin_objects.begin(); i != plugin_objects.end (); ++i) {
+		ARDOUR::PluginScanMessage(_("VST3"), *i, !(cache_only || cancelled()));
+		vst3_discover (*i, cache_only || cancelled ());
+	}
+
+	return cancelled() ? -1 : 0;
+}
+
+void
+PluginManager::vst3_plugin (string const& module_path, VST3Info const& i)
+{
+	PluginInfoPtr info (new VST3PluginInfo ());
+
+	info->path      = module_path;
+	info->index     = i.index;
+	info->unique_id = i.uid;
+	info->name      = i.name;
+	info->category  = i.category; // TODO process split at "|" -> tags
+	info->creator   = i.vendor;
+	info->n_inputs  = ChanCount();
+	info->n_outputs = ChanCount();
+
+	info->n_inputs.set_audio (i.n_inputs + i.n_aux_inputs);
+	info->n_inputs.set_midi (i.n_midi_inputs);
+
+	info->n_outputs.set_audio (i.n_outputs + i.n_aux_outputs);
+	info->n_outputs.set_midi (i.n_midi_outputs);
+
+	_vst3_plugin_info->push_back (info);
+
+	if (!info->category.empty ()) {
+		set_tags (info->type, info->unique_id, info->category, info->name, FromPlug);
+	}
+}
+
+int
+PluginManager::vst3_discover (string const& path, bool cache_only)
+{
+	string module_path = module_path_vst3 (path);
+	if (module_path.empty ()) {
+		return -1;
+	}
+
+	if (vst3_is_blacklisted (module_path)) {
+		return -1;
+	}
+
+	DEBUG_TRACE (DEBUG::PluginManager, string_compose ("VST3: discover %1 (%2)\n", path, module_path));
+
+	if (!cache_only && vst3_scanner_bin_path.empty ()) {
+		/* direct scan in the host's process */
+		vst3_blacklist (module_path);
+
+		if (! vst3_scan_and_cache (module_path, path, sigc::mem_fun (*this, &PluginManager::vst3_plugin))) {
+			DEBUG_TRACE (DEBUG::PluginManager, string_compose ("Cannot load VST3 at '%1'\n", path));
+			return -1;
+		}
+
+		vst3_whitelist (module_path);
+		return 0;
+	}
+
+	string cache_file = vst3_valid_cache_file (module_path);
+
+	bool run_scan = false;
+
+	XMLTree tree;
+	if (cache_file.empty ()) {
+		run_scan = true;
+	} else if (tree.read (cache_file)) {
+		/* valid cache file was found, now check version */
+		int cf_version = 0;
+		if (!tree.root()->get_property ("version", cf_version) || cf_version < 1) {
+			run_scan = true;
+		}
+	} else {
+		/* failed to parse XML */
+		run_scan = true;
+	}
+
+	if (!cache_only && run_scan) {
+		/* re/generate cache file */
+		vst3_blacklist (module_path);
+		if (!run_vst3_scanner_app (path)) {
+			return -1;
+		}
+
+		cache_file = vst3_valid_cache_file (module_path);
+
+		if (cache_file.empty ()) {
+			return -1;
+		}
+		/* re-read cache file */
+		if (!tree.read (cache_file)) {
+			error << string_compose (_("Cannot parse VST3 cache file '%1' for plugin '%2'"), cache_file, module_path) << endmsg;
+			return -1;
+		}
+		run_scan = false; // mark as scanned
+	}
+
+	if (cache_file.empty () || run_scan) {
+		/* cache file does not exist and cache_only == true,
+		 * or cache file is invalid (scan needed)
+		 */
+		return -1;
+	}
+
+	std::string module;
+	if (!tree.root()->get_property ("module", module) || module != module_path) {
+		error << string_compose (_("Invalid VST3 cache file '%1' for plugin '%2'"), cache_file, module_path) << endmsg;
+		return -1;
+	}
+
+	vst3_whitelist (module_path);
+
+	for (XMLNodeConstIterator i = tree.root()->children().begin(); i != tree.root()->children().end(); ++i) {
+		try {
+			VST3Info nfo (**i);
+			vst3_plugin (module_path, nfo);
+		} catch (...) {
+			error << string_compose (_("Corrupt VST3 cache file '%1' for plugin '%2'"), cache_file, module_path) << endmsg;
+			DEBUG_TRACE (DEBUG::PluginManager, string_compose ("Cannot load VST3 at '%1'\n", path));
+			continue;
+		}
+	}
+	return 0;
+}
+
+static void vst3_scanner_log (std::string msg, std::string bundle_path)
+{
+	PBD::info << string_compose ("VST3<%1>: %2", bundle_path, msg) << endmsg;
+}
+
+bool
+PluginManager::run_vst3_scanner_app (std::string bundle_path) const
+{
+	char **argp= (char**) calloc (5, sizeof (char*));
+	argp[0] = strdup (vst3_scanner_bin_path.c_str ());
+	argp[1] = strdup ("-q");
+	argp[2] = strdup ("-f");
+	argp[3] = strdup (bundle_path.c_str ());
+	argp[4] = 0;
+
+	ARDOUR::SystemExec scanner (vst3_scanner_bin_path, argp);
+	PBD::ScopedConnection c;
+	scanner.ReadStdout.connect_same_thread (c, boost::bind (&vst3_scanner_log, _1, bundle_path));
+
+	if (scanner.start (ARDOUR::SystemExec::MergeWithStdin)) {
+		PBD::error << string_compose (_("Cannot launch VST scanner app '%1': %2"), scanner_bin_path, strerror (errno)) << endmsg;
+		return false;
+	}
+
+	int timeout = Config->get_vst_scan_timeout(); // deciseconds
+	bool notime = (timeout <= 0);
+
+	while (scanner.is_running () && (notime || timeout > 0)) {
+		if (!notime && no_timeout ()) {
+			notime = true;
+			timeout = -1;
+		}
+
+		ARDOUR::PluginScanTimeout (timeout);
+		--timeout;
+		Glib::usleep (100000);
+
+		if (cancelled () || (!notime && timeout == 0)) {
+			scanner.terminate ();
+			/* may be partially written */
+			std::string module_path = module_path_vst3 (bundle_path);
+			if (!module_path.empty ()) {
+				g_unlink (vst3_cache_file (module_path).c_str ());
+			}
+			vst3_whitelist (module_path);
+			return false;
+		}
+	}
+	return true;
+}
+
+#endif // VST3_SUPPORT
+
 
 PluginManager::PluginStatusType
 PluginManager::get_status (const PluginInfoPtr& pi) const
@@ -1466,6 +1875,9 @@ PluginManager::save_statuses ()
 		case MacVST:
 			ofs << "MacVST";
 			break;
+		case VST3:
+			ofs << "VST3";
+			break;
 		case Lua:
 			ofs << "Lua";
 			break;
@@ -1562,6 +1974,8 @@ PluginManager::load_statuses ()
 			type = MacVST;
 		} else if (stype == "Lua") {
 			type = Lua;
+		} else if (stype == "VST3") {
+			type = VST3;
 		} else {
 			error << string_compose (_("unknown plugin type \"%1\" - ignored"), stype)
 			      << endmsg;
@@ -1728,6 +2142,34 @@ PluginManager::to_generic_vst (const PluginType t)
 	return t;
 }
 
+std::string
+PluginManager::plugin_type_name (const PluginType t, bool short_name)
+{
+#if defined WINDOWS_VST_SUPPORT && defined LXVST_SUPPORT
+	switch (t) {
+		case Windows_VST:
+			return short_name ? "VST" : "Windows-VST";
+		case LXVST:
+			return short_name ? "LXVST" : "Linux-VST";
+		default:
+			break;
+	}
+#endif
+
+	switch (t) {
+		case Windows_VST:
+		case LXVST:
+		case MacVST:
+			return short_name ? "VST" : "VST2";
+		case AudioUnit:
+			return short_name ? "AU" : enum_2_string (t);
+		case LADSPA:
+			return short_name ? "LV1" : enum_2_string (t);
+		default:
+			return enum_2_string (t);
+	}
+}
+
 struct SortByTag {
 	bool operator() (std::string a, std::string b) {
 		return a.compare (b) < 0;
@@ -2055,12 +2497,8 @@ PluginManager::ladspa_plugin_info ()
 const ARDOUR::PluginInfoList&
 PluginManager::lv2_plugin_info ()
 {
-#ifdef LV2_SUPPORT
 	assert(_lv2_plugin_info);
 	return *_lv2_plugin_info;
-#else
-	return _empty_plugin_info;
-#endif
 }
 
 const ARDOUR::PluginInfoList&
@@ -2074,6 +2512,17 @@ PluginManager::au_plugin_info ()
 	return _empty_plugin_info;
 }
 
+const ARDOUR::PluginInfoList&
+PluginManager::vst3_plugin_info ()
+{
+#ifdef VST3_SUPPORT
+	if (_vst3_plugin_info) {
+		return *_vst3_plugin_info;
+	}
+#endif
+	return _empty_plugin_info;
+}
+
 const ARDOUR::PluginInfoList&
 PluginManager::lua_plugin_info ()
 {
