@@ -1006,18 +1006,17 @@ vstfx_get_info (const char* dllpath, enum ARDOUR::PluginType type, enum VSTScanM
 		} else {
 			int timeout = PLUGIN_SCAN_TIMEOUT;
 			bool no_timeout = (timeout <= 0);
-			ARDOUR::PluginScanTimeout (timeout);
 			while (scanner.is_running () && (no_timeout || timeout > 0)) {
-				if (!no_timeout && !ARDOUR::PluginManager::instance ().no_timeout ()) {
-					if (timeout%5 == 0) {
-						ARDOUR::PluginScanTimeout (timeout);
-					}
-					--timeout;
+				if (!no_timeout && ARDOUR::PluginManager::instance().no_timeout()) {
+					no_timeout = true;
+					timeout = -1;
 				}
-				ARDOUR::GUIIdle ();
+
+				ARDOUR::PluginScanTimeout (timeout);
+				--timeout;
 				Glib::usleep (100000);
 
-				if (ARDOUR::PluginManager::instance ().cancelled ()) {
+				if (ARDOUR::PluginManager::instance ().cancelled () /*|| (!no_timeout && timeout == 0*)*/) {
 					// remove info file (might be incomplete)
 					vstfx_remove_infofile (dllpath);
 					// remove temporary blacklist file (scan incomplete)
