@@ -41,6 +41,7 @@
 #include "ardour/panner_shell.h"
 #include "ardour/plugin.h"
 #include "ardour/plugin_insert.h"
+#include "ardour/plugin_manager.h"
 #include "ardour/processor.h"
 #include "ardour/rc_configuration.h"
 #include "ardour/route.h"
@@ -87,6 +88,17 @@ debug_2byte_msg (std::string const& msg, int b0, int b1)
 #endif
 }
 
+bool
+FaderPort8::ProcessorCtrl::operator< (const FaderPort8::ProcessorCtrl& other) const
+{
+	if (ac->desc().display_priority == other.ac->desc().display_priority) {
+		return ac->parameter () < other.ac->parameter ();
+	}
+	/* sort higher priority first */
+	return ac->desc().display_priority > other.ac->desc().display_priority;
+}
+
+
 FaderPort8::FaderPort8 (Session& s)
 #ifdef FADERPORT16
 	: ControlProtocol (s, _("PreSonus FaderPort16"))
@@ -1177,7 +1189,7 @@ FaderPort8::assign_processor_ctrls ()
 	std::vector <ProcessorCtrl*> toggle_params;
 	std::vector <ProcessorCtrl*> slider_params;
 
-	for ( std::list <ProcessorCtrl>::iterator i = _proc_params.begin(); i != _proc_params.end(); ++i) {
+	for (std::list<ProcessorCtrl>::iterator i = _proc_params.begin(); i != _proc_params.end(); ++i) {
 		if ((*i).ac->toggled()) {
 			toggle_params.push_back (&(*i));
 		} else {
@@ -1397,9 +1409,13 @@ FaderPort8::select_plugin (int num)
 		if (n == "hidden") {
 			continue;
 		}
+
 		_proc_params.push_back (ProcessorCtrl (n, proc->automation_control (*i)));
 	}
 
+	/* sort by display priority */
+	_proc_params.sort ();
+
 	// TODO: open plugin GUI  if (_proc_params.size() > 0)
 
 	// display
@@ -1428,27 +1444,6 @@ FaderPort8::select_plugin_preset (size_t num)
 	assign_processor_ctrls ();
 }
 
-/* short 4 chars at most */
-static std::string plugintype (ARDOUR::PluginType t) {
-	switch (t) {
-		case AudioUnit:
-			return "AU";
-		case LADSPA:
-			return "LV1";
-		case LV2:
-			return "LV2";
-		case Windows_VST:
-		case LXVST:
-		case MacVST:
-			return "VST";
-		case Lua:
-			return "Lua";
-		default:
-			break;
-	}
-	return enum_2_string (t);
-}
-
 void
 FaderPort8::spill_plugins ()
 {
@@ -1540,7 +1535,7 @@ FaderPort8::spill_plugins ()
 		_ctrls.strip(id).select_button ().set_blinking (false);
 		_ctrls.strip(id).set_text_line (0, proc->name());
 		_ctrls.strip(id).set_text_line (1, pi->plugin()->maker());
-		_ctrls.strip(id).set_text_line (2, plugintype (pi->type()));
+		_ctrls.strip(id).set_text_line (2, PluginManager::plugin_type_name (pi->type()));
 		_ctrls.strip(id).set_text_line (3, "");
 
 		pi->ActiveChanged.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::spill_plugins, this), this);
@@ -1730,9 +1725,9 @@ FaderPort8::select_strip (boost::weak_ptr<Stripable> ws)
 # endif
 
 	if (shift_mod ()) {
-		ToggleStripableSelection (s);
+		toggle_stripable_selection (s);
 	} else {
-		SetStripableSelection (s);
+		set_stripable_selection (s);
 	}
 #else
 	/* tri-state selection: This allows to set the "first selected"
@@ -1741,9 +1736,9 @@ FaderPort8::select_strip (boost::weak_ptr<Stripable> ws)
 	 */
 	if (shift_mod ()) {
 		if (s->is_selected ()) {
-			RemoveStripableFromSelection (s);
+			remove_stripable_from_selection (s);
 		} else {
-			SetStripableSelection (s);
+			set_stripable_selection (s);
 		}
 		return;
 	}
@@ -1751,7 +1746,7 @@ FaderPort8::select_strip (boost::weak_ptr<Stripable> ws)
 		set_first_selected_stripable (s);
 		stripable_selection_changed ();
 	} else {
-		ToggleStripableSelection (s);
+		toggle_stripable_selection (s);
 	}
 #endif
 }
@@ -1995,9 +1990,9 @@ FaderPort8::select_prev_next (bool next)
 	if (!selected) {
 		if (strips.size() > 0) {
 			if (next) {
-				SetStripableSelection (strips.front ());
+				set_stripable_selection (strips.front ());
 			} else {
-				SetStripableSelection (strips.back ());
+				set_stripable_selection (strips.back ());
 			}
 		}
 		return;
@@ -2024,7 +2019,7 @@ FaderPort8::select_prev_next (bool next)
 	}
 
 	if (found && toselect) {
-		SetStripableSelection (toselect);
+		set_stripable_selection (toselect);
 	}
 }
 
