@@ -1,7 +1,7 @@
 ardour {
 	["type"]    = "EditorHook",
 	name        = "OSC Callback Example",
-	author      = "Ardour Lua Task Force",
+	author      = "Ardour Team",
 	description = "Send OSC messages",
 }
 
